package engine

import (
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/abbysale"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/abuseipdb"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/accuweather"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/adafruitio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/adzuna"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aeroworkflow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/agora"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aha"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airbrakeprojectkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airbrakeuserkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airship"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airtableapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/airvisual"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/alconost"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/alegra"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aletheiaapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/algoliaadminkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/alibaba"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/alienvault"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/allsports"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/amadeus"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ambee"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/amplitudeapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/anypoint"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apacta"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/api2cart"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apideck"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apiflash"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apifonica"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apimatic"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apiscience"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apitemplate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/appcues"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/appfollow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/appsynergy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/apptivo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/artsy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/asanaoauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/asanapersonalaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/assemblyai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/atera"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/audd"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/auth0managementapitoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/autodesk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/autoklose"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/autopilot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/avazapersonalaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aviationstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aws"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/axonaut"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/aylien"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ayrshare"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/azure"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bannerbear"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/baremetrics"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/baseapiio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/beamer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/beebole"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/besnappy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/besttime"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/billomat"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bitbar"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bitcoinaverage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bitfinex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bitlyaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bitmex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/blablabus"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/blazemeter"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/blitapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/blogger"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bombbomb"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/boostnote"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/borgbase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/brandfetch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/browserstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/browshot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/buddyns"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bugherd"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bugsnag"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/buildkite"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bulbul"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/bulksms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/buttercms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/caflou"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/calendarific"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/calendlyapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/calorieninja"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/campayn"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cannyio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/capsulecrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/captaindata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/carboninterface"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cashboard"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/caspio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/censys"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/centralstationcrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cexio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/chartmogul"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/chatbot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/chatfule"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/checio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/checklyhq"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/checkout"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/checkvist"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cicero"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/circleci"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clarifai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clearbit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clickhelp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clicksendsms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clickuppersonaltoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cliengo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clinchpad"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clockify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clockworksms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/closecrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudconvert"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudelements"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudflareapitoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudflarecakey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudimage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudmersive"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudplan"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloudsmith"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloverly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cloze"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/clustdoc"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/codacy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/codequiry"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coinapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coinbase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coinlayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coinlib"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/collect2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/column"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/commercejs"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/commodities"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/companyhub"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/confluent"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/contentfulpersonalaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/conversiontools"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/convertapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/convertkit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/convier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/copper"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/countrylayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/courier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/coveralls"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/craftmypdf"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/crossbrowsertesting"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/crowdin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/cryptocompare"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/currencycloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/currencyfreaks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/currencylayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/currencyscoop"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/currentsapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/customerguru"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/customerio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/d7network"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dandelion"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dareboost"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/databox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/datadogtoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/datafire"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/datagov"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/deepai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/deepgram"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/delighted"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/deputy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/detectify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/detectlanguage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dfuse"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/diffbot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/diggernaut"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/digitaloceantoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/discordbottoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/discordwebhook"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/disqus"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ditto"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dnscheck"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/documo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/doppler"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dotmailer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dovico"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dronahq"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/droneci"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dropbox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dwolla"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dynalist"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/dyspatch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/eagleeyenetworks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/easyinsight"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/edamam"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/edenai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/eightxeight"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/elasticemail"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/enablex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/enigma"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ethplorer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/etsyapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/everhour"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/exchangerateapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/exchangeratesapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/exportsdk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/extractorapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/facebookoauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/faceplusplus"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fakejson"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fastforex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fastlypersonaltoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/feedier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fetchrss"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fibery"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/figmapersonalaccesstoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fileio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/finage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/financialmodelingprep"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/findl"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/finnhub"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fixerio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flatio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fleetbase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flickr"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flightapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flightstats"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/float"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flowdash"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flowdock"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flowflu"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/flutterwave"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fmfw"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/formbucket"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/formcraft"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/formio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/foursquare"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/frameio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/freshbooks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/freshdesk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/front"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fulcrum"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fullstory"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fusebill"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/fxmarket"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gcp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geckoboard"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gengo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geoapify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geocode"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geocodify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geocodio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/geoipifi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/getgeoapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/getgist"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/getsandbox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/github"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/github_old"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/githubapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gitlab"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gitlabv2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gitter"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/glassnode"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/glitterlyapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gocanvas"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gocardless"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/goodday"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/graphcms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/graphhopper"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/groovehq"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/guardianapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gumroad"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/gyazo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/happi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/happyscribe"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/harvest"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hellosign"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/helpcrunch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/helpscout"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hereapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/heroku"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hiveage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/holidayapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/host"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/html2pdf"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hubspotapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/humanity"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hunter"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hybiscus"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/hypertrack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/iconfinder"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/iexapis"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/iexcloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/image4"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/imagekit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/imagga"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/impala"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/insightly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/instabot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/integromat"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/intercom"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/interseller"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/intrinio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/invoiceocean"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipgeolocation"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipinfodb"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipquality"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ipstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/jdbc"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/jiratoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/jotform"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/jumpcloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/juro"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kanban"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/karmacrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/keenio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kickbox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/klipfolio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/knapsackpro"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kontent"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kraken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kucoin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/kylas"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/languagelayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lastfm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/launchdarkly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/leadfeeder"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lendflow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lessannoyingcrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lexigram"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/linearapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/linenotify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/linkpreview"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/liveagent"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/livestorm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/loadmill"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/locationiq"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/loginradius"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lokalisetoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/loyverse"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/lunchmoney"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/luno"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/macaddress"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/madkudu"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/magicbell"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/magnetic"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailboxlayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailchimp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailerlite"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailgun"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailjetbasicauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailjetsms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailmodo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mailsac"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mandrill"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mapbox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mapquest"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/marketstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mattermostpersonaltoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mavenlink"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/maxmindlicense"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/meaningcloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mediastack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/meistertask"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mesibo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/messagebird"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/metaapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/metrilo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/microsoftteamswebhook"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/midise"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mindmeister"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/miro"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mite"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mixmax"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mockaroo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/moderation"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/monday"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/moonclerck"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/moonclerk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/moosend"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mrticktock"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/mux"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/myfreshworks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/myintervals"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nasdaqdatalink"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nethunt"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/netlify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/neutrinoapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/newrelicpersonalapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/newsapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/newscatcher"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nexmoapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nftport"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nicereply"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nightfall"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nimble"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nitro"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/noticeable"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/notion"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nozbeteams"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/numverify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nutritionix"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nylas"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/nytimes"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/oanda"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/okta"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/omnisend"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/onedesk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/onelogin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/onepagecrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/onesignal"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/onwaterio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/oopspam"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/opencagedata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/opengraphr"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/openuv"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/openweather"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/optimizely"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/owlbot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/packagecloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pagerdutyapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pandadoc"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pandascore"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paperform"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paralleldots"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/parsehub"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/parsers"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/partnerstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/passbase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pastebin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paydirtapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paymoapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paymongo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paypaloauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/paystack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pdflayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pdfshift"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/peopledatalabs"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pepipost"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pinata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pipedream"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pipedrive"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pivotaltracker"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pixabay"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/planviewleankit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/planyo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/plivo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/podio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pollsapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/poloniex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/polygon"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/positionstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/postageapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/postbacks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/posthog"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/postman"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/postmark"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/powrbot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/privatekey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/prospectcrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/prospectio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/protocolsio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/proxycrawl"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pubnubpublishkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pubnubsubscriptionkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/purestake"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pushbulletapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/pusherchannelkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/qase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/qualaroo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/qubole"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/quickmetrics"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rapidapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rawg"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/razorpay"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/reachmail"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/readme"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/reallysimplesystems"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rebrandly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rechargepayments"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/refiner"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rentman"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/repairshopr"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/restpack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/restpackhtmltopdfapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/restpackscreenshotapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/revampcrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ringcentral"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ritekit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/roaring"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rocketreach"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rockset"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/roninapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/route4me"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rownd"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/rubygems"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/runrunit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/salesblink"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/salescookie"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/salesflare"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/satismeterprojectkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/satismeterwritekey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/saucelabs"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scalewaykey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapeowl"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scraperapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scraperbox"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapersite"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapestack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapfly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapingant"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrapingbee"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/screenshotapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/screenshotlayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/scrutinizerci"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/securitytrails"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/segmentapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/selectpdf"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/semaphore"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sendbird"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sendbirdorganizationapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sendgrid"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sendinbluev2"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sentrytoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/serphouse"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/serpstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sheety"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sherpadesk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shipday"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shodankey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shortcut"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shotstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shutterstock"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/shutterstockoauth"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/signable"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/signalwire"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/signaturit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/signupgenius"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sigopt"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/simfin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/simplesat"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/simplynoted"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/simvoly"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sinchmessage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sirv"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/siteleaf"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/skrappio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/skybiometry"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/slack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/slackwebhook"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/smartsheets"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/smartystreets"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/smooch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/snipcart"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/snykkey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sonarcloud"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/speechtextai"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/splunkobservabilitytoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/spoonacular"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sportradar"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sportsmonk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/square"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/squareapp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/squarespace"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/squareup"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sslmate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/statuscake"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/statuspage"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/statuspal"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stitchdata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stockdata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/storecove"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stormboard"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stormglass"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/storyblok"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/storychief"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/strava"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/streak"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stripe"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/stytch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sugester"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/sumologickey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/supernotesapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/surveyanyplace"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/surveybot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/surveysparrow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/survicate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/swell"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/swiftype"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tallyfy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tatumio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/taxjar"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/teamgate"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/teamworkcrm"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/teamworkdesk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/teamworkspaces"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/technicalanalysisapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tefter"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/telegrambottoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/teletype"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/telnyx"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/terraformcloudpersonaltoken"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/testingbot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/text2data"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/textmagic"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/theoddsapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/thinkific"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/thousandeyes"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ticketmaster"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tickettailor"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tiingo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/timecamp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/timezoneapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tmetric"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/todoist"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tomorrowio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tomtom"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tradier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/travelpayouts"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/travisci"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/trelloapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twelvedata"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twilio"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twitch"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/twitter"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/tyntec"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/typeform"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/typetalk"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/ubidots"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/uclassify"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/unifyid"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/unplugg"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/unsplash"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/upcdatabase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/uplead"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/uploadcare"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/uptimerobot"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/upwave"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/uri"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/urlscan"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/userflow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/userstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vatlayer"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vbout"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vercel"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/verifier"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/verimail"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/veriphone"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/versioneye"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/viewneo"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/virustotal"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/visualcrossing"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/voicegain"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/voodoosms"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vouchery"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vpnapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vultrapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/vyte"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/walkscore"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/weatherbit"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/weatherstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/webex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/webflow"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/webscraper"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/webscraping"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/whoxy"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/wistia"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/worksnaps"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/workstack"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/worldcoinindex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/worldweather"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/wrike"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/yandex"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/yelp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/youneedabudget"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/yousign"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/youtubeapikey"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zendeskapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zenkitapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zenrows"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zenscrape"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zenserp"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zeplin"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zerobounce"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zipapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zipbooks"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zipcodeapi"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zipcodebase"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zonkafeedback"
	"github.com/trufflesecurity/trufflehog/v3/pkg/detectors/zulipchat"
)

func DefaultDetectors() []detectors.Detector {
	return []detectors.Detector{
		&heroku.Scanner{},
		&linearapi.Scanner{},
		&alibaba.Scanner{},
		&aws.Scanner{},
		&azure.Scanner{},
		&slack.Scanner{}, // has 4 secret types
		&gitlabv2.Scanner{},
		&gitlab.Scanner{},
		&sendgrid.Scanner{},
		&mailchimp.Scanner{},
		&okta.Scanner{},
		&onelogin.Scanner{},
		&heroku.Scanner{},
		&dropbox.Scanner{},
		&linearapi.Scanner{},
		&stripe.Scanner{},
		&square.Scanner{},
		&squareapp.Scanner{},
		&pivotaltracker.Scanner{},
		&github.Scanner{},
		&twilio.Scanner{},
		&gcp.Scanner{},
		&circleci.Scanner{},
		&uri.Scanner{},
		&razorpay.Scanner{},
		&jdbc.Scanner{},
		&privatekey.Scanner{},
		&maxmindlicense.Scanner{},
		&airtableapikey.Scanner{},
		&bitfinex.Scanner{},
		&telegrambottoken.Scanner{},
		&clarifai.Scanner{},
		&cloudflareapitoken.Scanner{},
		&cloudflarecakey.Scanner{},
		// &cloudflareglobalapikey.Scanner{},
		&terraformcloudpersonaltoken.Scanner{},
		&asanapersonalaccesstoken.Scanner{},
		&trelloapikey.Scanner{},
		&mapbox.Scanner{},
		&mailgun.Scanner{},
		&mailjetbasicauth.Scanner{},
		&auth0managementapitoken.Scanner{},
		// &auth0oauth.Scanner{},
		&mailjetsms.Scanner{},
		&digitaloceantoken.Scanner{},
		&paystack.Scanner{},
		&contentfulpersonalaccesstoken.Scanner{},
		&hunter.Scanner{},
		&sendinbluev2.Scanner{},
		&elasticemail.Scanner{},
		&messagebird.Scanner{},
		&microsoftteamswebhook.Scanner{},
		&plivo.Scanner{},
		&rapidapi.Scanner{},
		&discordbottoken.Scanner{},
		&netlify.Scanner{},
		&hubspotapikey.Scanner{},
		&travisci.Scanner{},
		&scalewaykey.Scanner{},
		&fastlypersonaltoken.Scanner{},
		&snykkey.Scanner{},
		&postmark.Scanner{},
		&figmapersonalaccesstoken.Scanner{},
		&github_old.Scanner{},
		&webex.Scanner{},
		&segmentapikey.Scanner{},
		&vultrapikey.Scanner{},
		// &ibmclouduserkey.Scanner{},
		&pepipost.Scanner{},
		&postman.Scanner{},
		&nexmoapikey.Scanner{},
		&newrelicpersonalapikey.Scanner{},
		&pushbulletapikey.Scanner{},
		&paypaloauth.Scanner{},
		&datadogtoken.Scanner{},
		&airbrakeuserkey.Scanner{},
		&sumologickey.Scanner{},
		&pagerdutyapikey.Scanner{},
		&jiratoken.Scanner{},
		&airbrakeprojectkey.Scanner{},
		&calendlyapikey.Scanner{},
		&bitlyaccesstoken.Scanner{},
		&youtubeapikey.Scanner{},
		&coinbase.Scanner{},
		&confluent.Scanner{},
		&zendeskapi.Scanner{},
		&etsyapikey.Scanner{},
		&facebookoauth.Scanner{},
		&amplitudeapikey.Scanner{},
		&pubnubpublishkey.Scanner{},
		&sentrytoken.Scanner{},
		&githubapp.Scanner{},
		&slackwebhook.Scanner{},
		// &spotifykey.Scanner{},
		&discordwebhook.Scanner{},
		// &zapierwebhook.Scanner{},
		&pubnubsubscriptionkey.Scanner{},
		// &plaidkey.Scanner{},
		&calendarific.Scanner{},
		&jumpcloud.Scanner{},
		&notion.Scanner{},
		&droneci.Scanner{},
		&ipstack.Scanner{},
		// &adobeio.Scanner{},
		&sslmate.Scanner{},
		&buildkite.Scanner{},
		&shodankey.Scanner{},
		&lokalisetoken.Scanner{},
		&twelvedata.Scanner{},
		&intercom.Scanner{},
		&d7network.Scanner{},
		&buttercms.Scanner{},
		&taxjar.Scanner{},
		&zerobounce.Scanner{},
		&fixerio.Scanner{},
		&verimail.Scanner{},
		&helpscout.Scanner{},
		&beamer.Scanner{},
		&liveagent.Scanner{},
		&pipedrive.Scanner{},
		&cannyio.Scanner{},
		&vercel.Scanner{},
		&posthog.Scanner{},
		&mandrill.Scanner{},
		&mailmodo.Scanner{},
		&flutterwave.Scanner{},
		&algoliaadminkey.Scanner{},
		&mattermostpersonaltoken.Scanner{},
		&splunkobservabilitytoken.Scanner{},
		&simvoly.Scanner{},
		&surveysparrow.Scanner{},
		&survicate.Scanner{},
		&omnisend.Scanner{},
		&getgist.Scanner{},
		&groovehq.Scanner{},
		&newsapi.Scanner{},
		&helpcrunch.Scanner{},
		// &linemessaging.Scanner{},
		&launchdarkly.Scanner{},
		&salesflare.Scanner{},
		&chatbot.Scanner{},
		&nftport.Scanner{},
		&coveralls.Scanner{},
		&rubygems.Scanner{},
		&webflow.Scanner{},
		&graphcms.Scanner{},
		&anypoint.Scanner{},
		&frameio.Scanner{},
		&zonkafeedback.Scanner{},
		&surveybot.Scanner{},
		&mailerlite.Scanner{},
		&qualaroo.Scanner{},
		&simplesat.Scanner{},
		&convertkit.Scanner{},
		&clockworksms.Scanner{},
		&apideck.Scanner{},
		&zeplin.Scanner{},
		&myfreshworks.Scanner{},
		&satismeterwritekey.Scanner{},
		&customerio.Scanner{},
		&clicksendsms.Scanner{},
		&copper.Scanner{},
		&skrappio.Scanner{},
		&delighted.Scanner{},
		&abbysale.Scanner{},
		&feedier.Scanner{},
		&prospectio.Scanner{},
		&nytimes.Scanner{},
		&powrbot.Scanner{},
		&magnetic.Scanner{},
		&polygon.Scanner{},
		&smartsheets.Scanner{},
		// &wepay.Scanner{},
		// &artifactory.Scanner{},
		&integromat.Scanner{},
		&linenotify.Scanner{},
		&float.Scanner{},
		&monday.Scanner{},
		// &debounce.Scanner{},
		&guardianapi.Scanner{},
		&squarespace.Scanner{},
		&wrike.Scanner{},
		&storyblok.Scanner{},
		&salesblink.Scanner{},
		&campayn.Scanner{},
		&clinchpad.Scanner{},
		&companyhub.Scanner{},
		&dyspatch.Scanner{},
		&harvest.Scanner{},
		&moosend.Scanner{},
		&openweather.Scanner{},
		&siteleaf.Scanner{},
		&flowflu.Scanner{},
		&nimble.Scanner{},
		&lessannoyingcrm.Scanner{},
		&nethunt.Scanner{},
		&apptivo.Scanner{},
		&capsulecrm.Scanner{},
		&insightly.Scanner{},
		&kylas.Scanner{},
		&onepagecrm.Scanner{},
		&reallysimplesystems.Scanner{},
		&timezoneapi.Scanner{},
		&everhour.Scanner{},
		&jotform.Scanner{},
		&workstack.Scanner{},
		&clockify.Scanner{},
		&karmacrm.Scanner{},
		&revampcrm.Scanner{},
		// &apollo.Scanner{},
		&artsy.Scanner{},
		&vpnapi.Scanner{},
		&dnscheck.Scanner{},
		// &toggltrack.Scanner{},
		&ethplorer.Scanner{},
		&fulcrum.Scanner{},
		&metrilo.Scanner{},
		&salescookie.Scanner{},
		&geoipifi.Scanner{},
		&yandex.Scanner{},
		&airship.Scanner{},
		&refiner.Scanner{},
		&pandadoc.Scanner{},
		&juro.Scanner{},
		&documo.Scanner{},
		&roninapp.Scanner{},
		&doppler.Scanner{},
		&codacy.Scanner{},
		&gocardless.Scanner{},
		&alconost.Scanner{},
		&rawg.Scanner{},
		&opengraphr.Scanner{},
		&accuweather.Scanner{},
		&tomtom.Scanner{},
		&teamgate.Scanner{},
		&bulbul.Scanner{},
		&centralstationcrm.Scanner{},
		&tyntec.Scanner{},
		&axonaut.Scanner{},
		&kraken.Scanner{},
		&easyinsight.Scanner{},
		&closecrm.Scanner{},
		&customerguru.Scanner{},
		&prospectcrm.Scanner{},
		&surveyanyplace.Scanner{},
		&ubidots.Scanner{},
		sinchmessage.Scanner{},
		ayrshare.Scanner{},
		mailboxlayer.Scanner{},
		satismeterprojectkey.Scanner{},
		pusherchannelkey.Scanner{},
		imagekit.Scanner{},
		asanaoauth.Scanner{},
		// getemail.Scanner{},
		rocketreach.Scanner{},
		// raven.Scanner{},
		kontent.Scanner{},
		cloudplan.Scanner{},
		autoklose.Scanner{},
		appcues.Scanner{},
		// getemails.Scanner{},
		leadfeeder.Scanner{},
		uplead.Scanner{},
		audd.Scanner{},
		bitbar.Scanner{},
		// abstract.Scanner{},
		exchangerateapi.Scanner{},
		currencycloud.Scanner{},
		finage.Scanner{},
		adafruitio.Scanner{},
		storychief.Scanner{},
		tradier.Scanner{},
		hellosign.Scanner{},
		dwolla.Scanner{},
		voicegain.Scanner{},
		ambee.Scanner{},
		bannerbear.Scanner{},
		hypertrack.Scanner{},
		holidayapi.Scanner{},
		lastfm.Scanner{},
		currencylayer.Scanner{},
		coinlib.Scanner{},
		agora.Scanner{},
		marketstack.Scanner{},
		exchangeratesapi.Scanner{},
		faceplusplus.Scanner{},
		baremetrics.Scanner{},
		getgeoapi.Scanner{},
		alegra.Scanner{},
		tatumio.Scanner{},
		deepgram.Scanner{},
		brandfetch.Scanner{},
		typeform.Scanner{},
		blablabus.Scanner{},
		fxmarket.Scanner{},
		ipapi.Scanner{},
		clearbit.Scanner{},
		spoonacular.Scanner{},
		finnhub.Scanner{},
		checkout.Scanner{},
		// mixpanel.Scanner{},
		ipgeolocation.Scanner{},
		tmetric.Scanner{},
		fullstory.Scanner{},
		noticeable.Scanner{},
		currencyscoop.Scanner{},
		scrapingbee.Scanner{},
		todoist.Scanner{},
		owlbot.Scanner{},
		keenio.Scanner{},
		dovico.Scanner{},
		html2pdf.Scanner{},
		yousign.Scanner{},
		fleetbase.Scanner{},
		cloudmersive.Scanner{},
		imagga.Scanner{},
		visualcrossing.Scanner{},
		bugsnag.Scanner{},
		runrunit.Scanner{},
		assemblyai.Scanner{},
		loyverse.Scanner{},
		swell.Scanner{},
		crowdin.Scanner{},
		nutritionix.Scanner{},
		mapquest.Scanner{},
		clickuppersonaltoken.Scanner{},
		tiingo.Scanner{},
		billomat.Scanner{},
		blogger.Scanner{},
		front.Scanner{},
		nitro.Scanner{},
		apify.Scanner{},
		dynalist.Scanner{},
		mavenlink.Scanner{},
		sportsmonk.Scanner{},
		bitcoinaverage.Scanner{},
		zipcodeapi.Scanner{},
		gyazo.Scanner{},
		fakejson.Scanner{},
		// sparkpost.Scanner{},
		locationiq.Scanner{},
		saucelabs.Scanner{},
		enigma.Scanner{},
		clickhelp.Scanner{},
		adzuna.Scanner{},
		vouchery.Scanner{},
		currentsapi.Scanner{},
		flickr.Scanner{},
		apiflash.Scanner{},
		geocodio.Scanner{},
		datagov.Scanner{},
		tomorrowio.Scanner{},
		lexigram.Scanner{},
		securitytrails.Scanner{},
		foursquare.Scanner{},
		browshot.Scanner{},
		edamam.Scanner{},
		alienvault.Scanner{},
		protocolsio.Scanner{},
		coinlayer.Scanner{},
		commercejs.Scanner{},
		detectlanguage.Scanner{},
		worldcoinindex.Scanner{},
		airvisual.Scanner{},
		sheety.Scanner{},
		financialmodelingprep.Scanner{},
		stormglass.Scanner{},
		oopspam.Scanner{},
		unsplash.Scanner{},
		allsports.Scanner{},
		amadeus.Scanner{},
		ringcentral.Scanner{},
		pixabay.Scanner{},
		ipify.Scanner{},
		youneedabudget.Scanner{},
		macaddress.Scanner{},
		languagelayer.Scanner{},
		gengo.Scanner{},
		aylien.Scanner{},
		shutterstock.Scanner{},
		hereapi.Scanner{},
		text2data.Scanner{},
		readme.Scanner{},
		pastebin.Scanner{},
		vatlayer.Scanner{},
		verifier.Scanner{},
		onwaterio.Scanner{},
		graphhopper.Scanner{},
		scraperapi.Scanner{},
		ritekit.Scanner{},
		linkpreview.Scanner{},
		dotmailer.Scanner{},
		api2cart.Scanner{},
		virustotal.Scanner{},
		numverify.Scanner{},
		pdflayer.Scanner{},
		geocode.Scanner{},
		iconfinder.Scanner{},
		// m3o.Scanner{},
		mesibo.Scanner{},
		impala.Scanner{},
		besttime.Scanner{},
		currencyfreaks.Scanner{},
		humanity.Scanner{},
		loginradius.Scanner{},
		stockdata.Scanner{},
		flatio.Scanner{},
		openuv.Scanner{},
		snipcart.Scanner{},
		screenshotapi.Scanner{},
		cryptocompare.Scanner{},
		happyscribe.Scanner{},
		geocodify.Scanner{},
		bombbomb.Scanner{},
		serpstack.Scanner{},
		zenserp.Scanner{},
		restpackscreenshotapi.Scanner{},
		shortcut.Scanner{},
		nasdaqdatalink.Scanner{},
		quickmetrics.Scanner{},
		neutrinoapi.Scanner{},
		bitmex.Scanner{},
		deepai.Scanner{},
		host.Scanner{},
		pdfshift.Scanner{},
		fetchrss.Scanner{},
		proxycrawl.Scanner{},
		storecove.Scanner{},
		fileio.Scanner{},
		coinapi.Scanner{},
		stytch.Scanner{},
		signupgenius.Scanner{},
		streak.Scanner{},
		route4me.Scanner{},
		opencagedata.Scanner{},
		positionstack.Scanner{},
		upcdatabase.Scanner{},
		commodities.Scanner{},
		glassnode.Scanner{},
		optimizely.Scanner{},
		censys.Scanner{},
		scraperbox.Scanner{},
		passbase.Scanner{},
		ticketmaster.Scanner{},
		datafire.Scanner{},
		iexcloud.Scanner{},
		partnerstack.Scanner{},
		qubole.Scanner{},
		poloniex.Scanner{},
		shipday.Scanner{},
		stitchdata.Scanner{},
		hiveage.Scanner{},
		technicalanalysisapi.Scanner{},
		smartystreets.Scanner{},
		shutterstockoauth.Scanner{},
		newscatcher.Scanner{},
		postageapp.Scanner{},
		unplugg.Scanner{},
		paymongo.Scanner{},
		flightapi.Scanner{},
		countrylayer.Scanner{},
		veriphone.Scanner{},
		ipinfodb.Scanner{},
		mediastack.Scanner{},
		screenshotlayer.Scanner{},
		userstack.Scanner{},
		edenai.Scanner{},
		urlscan.Scanner{},
		zenscrape.Scanner{},
		// dailyco.Scanner{},
		nicereply.Scanner{},
		// hive.Scanner{},
		clustdoc.Scanner{},
		scrapingant.Scanner{},
		kickbox.Scanner{},
		scrapeowl.Scanner{},
		rebrandly.Scanner{},
		dandelion.Scanner{},
		baseapiio.Scanner{},
		purestake.Scanner{},
		carboninterface.Scanner{},
		signaturit.Scanner{},
		blitapp.Scanner{},
		restpackhtmltopdfapi.Scanner{},
		webscraping.Scanner{},
		// sentiment.Scanner{},
		geoapify.Scanner{},
		dfuse.Scanner{},
		gitter.Scanner{},
		autopilot.Scanner{},
		aletheiaapi.Scanner{},
		intrinio.Scanner{},
		aviationstack.Scanner{},
		scrapestack.Scanner{},
		restpack.Scanner{},
		cloverly.Scanner{},
		thinkific.Scanner{},
		meaningcloud.Scanner{},
		skybiometry.Scanner{},
		appfollow.Scanner{},
		abuseipdb.Scanner{},
		squareup.Scanner{},
		zipbooks.Scanner{},
		roaring.Scanner{},
		signalwire.Scanner{},
		weatherbit.Scanner{},
		textmagic.Scanner{},
		telnyx.Scanner{},
		calorieninja.Scanner{},
		vyte.Scanner{},
		walkscore.Scanner{},
		planyo.Scanner{},
		zipapi.Scanner{},
		mailsac.Scanner{},
		unifyid.Scanner{},
		worldweather.Scanner{},
		strava.Scanner{},
		autodesk.Scanner{},
		serphouse.Scanner{},
		paralleldots.Scanner{},
		semaphore.Scanner{},
		nylas.Scanner{},
		weatherstack.Scanner{},
		ipquality.Scanner{},
		blazemeter.Scanner{},
		cicero.Scanner{},
		onedesk.Scanner{},
		bugherd.Scanner{},
		whoxy.Scanner{},
		smooch.Scanner{},
		apifonica.Scanner{},
		fusebill.Scanner{},
		goodday.Scanner{},
		getsandbox.Scanner{},
		freshdesk.Scanner{},
		teamworkdesk.Scanner{},
		tallyfy.Scanner{},
		apimatic.Scanner{},
		moonclerck.Scanner{},
		boostnote.Scanner{},
		freshbooks.Scanner{},
		cashboard.Scanner{},
		thousandeyes.Scanner{},
		zenkitapi.Scanner{},
		sherpadesk.Scanner{},
		shotstack.Scanner{},
		scrapersite.Scanner{},
		luno.Scanner{},
		apacta.Scanner{},
		fmfw.Scanner{},
		courier.Scanner{},
		checkvist.Scanner{},
		invoiceocean.Scanner{},
		travelpayouts.Scanner{},
		mixmax.Scanner{},
		cloze.Scanner{},
		supernotesapi.Scanner{},
		fastforex.Scanner{},
		sirv.Scanner{},
		teamworkcrm.Scanner{},
		geckoboard.Scanner{},
		appsynergy.Scanner{},
		findl.Scanner{},
		simplynoted.Scanner{},
		pandascore.Scanner{},
		gocanvas.Scanner{},
		formio.Scanner{},
		livestorm.Scanner{},
		// manifest.Scanner{},
		formbucket.Scanner{},
		apiscience.Scanner{},
		dronahq.Scanner{},
		webscraper.Scanner{},
		versioneye.Scanner{},
		rownd.Scanner{},
		diffbot.Scanner{},
		nozbeteams.Scanner{},
		pipedream.Scanner{},
		paymoapp.Scanner{},
		peopledatalabs.Scanner{},
		mite.Scanner{},
		mindmeister.Scanner{},
		deputy.Scanner{},
		eagleeyenetworks.Scanner{},
		sigopt.Scanner{},
		lendflow.Scanner{},
		meistertask.Scanner{},
		mrticktock.Scanner{},
		beebole.Scanner{},
		theoddsapi.Scanner{},
		oanda.Scanner{},
		scrapfly.Scanner{},
		kanban.Scanner{},
		upwave.Scanner{},
		ditto.Scanner{},
		buddyns.Scanner{},
		checio.Scanner{},
		happi.Scanner{},
		kucoin.Scanner{},
		eightxeight.Scanner{},
		avazapersonalaccesstoken.Scanner{},
		selectpdf.Scanner{},
		madkudu.Scanner{},
		borgbase.Scanner{},
		cliengo.Scanner{},
		swiftype.Scanner{},
		viewneo.Scanner{},
		planviewleankit.Scanner{},
		cloudimage.Scanner{},
		worksnaps.Scanner{},
		caspio.Scanner{},
		caflou.Scanner{},
		enablex.Scanner{},
		checklyhq.Scanner{},
		teamworkspaces.Scanner{},
		cloudelements.Scanner{},
		captaindata.Scanner{},
		uploadcare.Scanner{},
		moderation.Scanner{},
		myintervals.Scanner{},
		klipfolio.Scanner{},
		flightstats.Scanner{},
		sendbird.Scanner{},
		cexio.Scanner{},
		repairshopr.Scanner{},
		metaapi.Scanner{},
		aeroworkflow.Scanner{},
		column.Scanner{},
		sugester.Scanner{},
		sendbirdorganizationapi.Scanner{},
		chatfule.Scanner{},
		convier.Scanner{},
		midise.Scanner{},
		loadmill.Scanner{},
		magicbell.Scanner{},
		glitterlyapi.Scanner{},
		apitemplate.Scanner{},
		knapsackpro.Scanner{},
		twitter.Scanner{},
		timecamp.Scanner{},
		signable.Scanner{},
		teletype.Scanner{},
		wistia.Scanner{},
		hybiscus.Scanner{},
		miro.Scanner{},
		moonclerk.Scanner{},
		codequiry.Scanner{},
		qase.Scanner{},
		extractorapi.Scanner{},
		craftmypdf.Scanner{},
		// generic.Scanner{},
		userflow.Scanner{},
		mockaroo.Scanner{},
		statuspage.Scanner{},
		statuspal.Scanner{},
		testingbot.Scanner{},
		conversiontools.Scanner{},
		parsers.Scanner{},
		scrutinizerci.Scanner{},
		sonarcloud.Scanner{},
		dareboost.Scanner{},
		pinata.Scanner{},
		exportsdk.Scanner{},
		rechargepayments.Scanner{},
		browserstack.Scanner{},
		image4.Scanner{},
		crossbrowsertesting.Scanner{},
		flowdash.Scanner{},
		lunchmoney.Scanner{},
		atera.Scanner{},
		flowdock.Scanner{},
		parsehub.Scanner{},
		voodoosms.Scanner{},
		yelp.Scanner{},
		podio.Scanner{},
		rockset.Scanner{},
		aha.Scanner{},
		packagecloud.Scanner{},
		cloudsmith.Scanner{},
		nightfall.Scanner{},
		mux.Scanner{},
		statuscake.Scanner{},
		formcraft.Scanner{},
		sportradar.Scanner{},
		paperform.Scanner{},
		zulipchat.Scanner{},
		iexapis.Scanner{},
		detectify.Scanner{},
		reachmail.Scanner{},
		gumroad.Scanner{},
		typetalk.Scanner{},
		chartmogul.Scanner{},
		fibery.Scanner{},
		uptimerobot.Scanner{},
		paydirtapp.Scanner{},
		disqus.Scanner{},
		bulksms.Scanner{},
		onesignal.Scanner{},
		stormboard.Scanner{},
		interseller.Scanner{},
		tickettailor.Scanner{},
		twitch.Scanner{},
		rentman.Scanner{},
		tefter.Scanner{},
		pollsapi.Scanner{},
		diggernaut.Scanner{},
		zenrows.Scanner{},
		instabot.Scanner{},
		simfin.Scanner{},
		vbout.Scanner{},
		besnappy.Scanner{},
		convertapi.Scanner{},
		cloudconvert.Scanner{},
		zipcodebase.Scanner{},
		speechtextai.Scanner{},
		databox.Scanner{},
		postbacks.Scanner{},
		collect2.Scanner{},
		uclassify.Scanner{},
	}
}
